@@ -158,6 +158,9 @@ class PlatformJson(pydantic.BaseModel):
     operatorID: Optional[str] = ""
     sessionID: Optional[Union[str, int]] = ""
     mouseID: Optional[Union[str, int]] = ""
+    project: Optional[str] = ""
+    hab: Optional[bool] = None
+    
     DiINotes: Dict[str, Union[str, int]] = dict(
         EndTime="", StartTime="", dii_description="", times_dipped="", previous_uses="",
     )
@@ -198,28 +201,30 @@ class PlatformJson(pydantic.BaseModel):
     manifest_creation_time: Union[PlatformJsonDateTime, str] = ''
     workflow_complete_time: Union[PlatformJsonDateTime, str] = ''
     
-    manipulator_coordinates: Dict[str, Dict[str, float | str]] = pydantic.Field(default_factory=dict)
+    manipulator_coordinates: Dict[str, Dict[Any, Any]] = pydantic.Field(default_factory=dict)
 
     files: Dict[str, Dict[str, str]] = pydantic.Field(default_factory=dict)
 
     def update(self, field, new) -> None:
         existing = getattr(self, field)
-        if not new or existing == new:
+        if (not new and new is not False) or existing == new:
             return
-        logger.info('Updating %s %s: %s -> %s', self.path.name, field, existing, new)
+        print('Updating %s %s: %s -> %s', self.path.name, field, existing, new)
         setattr(self, field, new)
     
 def update_from_session(pj: PlatformJson, session) -> None:
     "Updates fields in a platform json file."
     
     with pj.write_disabled():
-        pj.update('operatorID', session.user.id)
-        pj.update('sessionID', session.id)
-        pj.update('mouseID', session.mouse.id)
+        pj.update('operatorID', str(session.user)) # don't need to convert here, `update` will compare values with existing
+        pj.update('sessionID', str(session.id))
+        pj.update('mouseID', str(session.mouse.id))
         pj.update('stimulus_name', session.lims['stimulus_name'])
         if pj.script_name:
             with contextlib.suppress(Exception):
                 pj.update('script_name', np_config.local_to_unc(session.rig.stim, pj.script_name))
         pj.update('foraging_id', session.foraging_id)
+        pj.update('project', session.project.id)
+        pj.update('hab', session.is_hab)
         
     pj.write()
